@@ -51,6 +51,8 @@
 #include "gvfsdaemonprotocol.h"
 #include "gvfsdaemonutils.h"
 
+static SoupSession *the_session;
+
 G_DEFINE_TYPE (GVfsBackendHttp, g_vfs_backend_http, G_VFS_TYPE_BACKEND)
 
 static void
@@ -63,83 +65,19 @@ g_vfs_backend_http_finalize (GObject *object)
   if (backend->mount_base)
     soup_uri_free (backend->mount_base);
 
-  soup_session_abort (backend->session);
   g_object_unref (backend->session);
 
-  soup_session_abort (backend->session_async);
-  g_object_unref (backend->session_async);
-
 
   if (G_OBJECT_CLASS (g_vfs_backend_http_parent_class)->finalize)
     (*G_OBJECT_CLASS (g_vfs_backend_http_parent_class)->finalize) (object);
 }
 
-#define DEBUG_MAX_BODY_SIZE (100 * 1024 * 1024)
-
 static void
 g_vfs_backend_http_init (GVfsBackendHttp *backend)
 {
-  const char         *debug;
-  SoupSessionFeature *proxy_resolver;
-  SoupSessionFeature *cookie_jar;
-  SoupSessionFeature *content_decoder;
-
   g_vfs_backend_set_user_visible (G_VFS_BACKEND (backend), FALSE);
 
-  backend->session = soup_session_sync_new_with_options ("user-agent",
-                                                         "gvfs/" VERSION,
-                                                         NULL);
-
-  backend->session_async = soup_session_async_new_with_options ("user-agent",
-                                                                "gvfs/" VERSION,
-                                                                NULL);
-  /* SoupRequester seems to depend on use-thread-context */
-  g_object_set (G_OBJECT (backend->session_async), "use-thread-context", TRUE, NULL);
-
-  /* Proxy handling */
-  proxy_resolver = g_object_new (SOUP_TYPE_PROXY_RESOLVER_DEFAULT, NULL);
-  soup_session_add_feature (backend->session, proxy_resolver);
-  soup_session_add_feature (backend->session_async, proxy_resolver);
-  g_object_unref (proxy_resolver);
-
-  /* Cookie handling - stored temporarlly in memory, mostly useful for
-   * authentication in WebDAV. */
-  cookie_jar = g_object_new (SOUP_TYPE_COOKIE_JAR, NULL);
-  soup_session_add_feature (backend->session, cookie_jar);
-  soup_session_add_feature (backend->session_async, cookie_jar);
-  g_object_unref (cookie_jar);
-
-  /* Send Accept-Language header (see bug 166795) */
-  g_object_set (backend->session, "accept-language-auto", TRUE, NULL);
-  g_object_set (backend->session_async, "accept-language-auto", TRUE, NULL);
-
-  /* Handle decompression automatically */
-  content_decoder = g_object_new (SOUP_TYPE_CONTENT_DECODER, NULL);
-  soup_session_add_feature (backend->session, content_decoder);
-  soup_session_add_feature (backend->session_async, content_decoder);
-  g_object_unref (content_decoder);
-
-  /* Logging */
-  debug = g_getenv ("GVFS_HTTP_DEBUG");
-  if (debug)
-    {
-      SoupLogger         *logger;
-      SoupLoggerLogLevel  level;
-
-      if (g_ascii_strcasecmp (debug, "all") ||
-          g_ascii_strcasecmp (debug, "body"))
-        level = SOUP_LOGGER_LOG_BODY;
-      else if (g_ascii_strcasecmp (debug, "header"))
-        level = SOUP_LOGGER_LOG_HEADERS;
-      else
-        level = SOUP_LOGGER_LOG_MINIMAL;
-
-      logger = soup_logger_new (level, DEBUG_MAX_BODY_SIZE);
-      soup_session_add_feature (backend->session, SOUP_SESSION_FEATURE (logger));
-      soup_session_add_feature (backend->session_async, SOUP_SESSION_FEATURE (logger));
-      g_object_unref (logger);
-    }
-
+  backend->session = g_object_ref (the_session);
 }
 
 /* ************************************************************************* */
@@ -282,7 +220,7 @@ http_backend_queue_message (GVfsBackend         *backend,
 {
   GVfsBackendHttp *op_backend = G_VFS_BACKEND_HTTP (backend);
 
-  soup_session_queue_message (op_backend->session_async, msg,
+  soup_session_queue_message (op_backend->session, msg,
                               callback, user_data);
 }
 /* ************************************************************************* */
@@ -410,7 +348,7 @@ http_backend_open_for_read (GVfsBackend *backend,
 
   op_backend = G_VFS_BACKEND_HTTP (backend);
 
-  stream = g_vfs_http_input_stream_new (op_backend->session_async, uri);
+  stream = g_vfs_http_input_stream_new (op_backend->session, uri);
 
   g_vfs_http_input_stream_send_async (stream,
 				      G_PRIORITY_DEFAULT,
@@ -721,9 +659,14 @@ try_query_info_on_read (GVfsBackend           *backend,
 }
 
 
+#define DEBUG_MAX_BODY_SIZE (100 * 1024 * 1024)
+
 static void
 g_vfs_backend_http_class_init (GVfsBackendHttpClass *klass)
 {
+  const char         *debug;
+  SoupSessionFeature *cookie_jar;
+
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
   GVfsBackendClass *backend_class;
 
@@ -738,4 +681,40 @@ g_vfs_backend_http_class_init (GVfsBackendHttpClass *klass)
   backend_class->try_close_read         = try_close_read;
   backend_class->try_query_info         = try_query_info;
   backend_class->try_query_info_on_read = try_query_info_on_read;
+
+  /* Initialize the SoupSession, common to all backend instances */
+  the_session = soup_session_new_with_options ("user-agent",
+                                               "gvfs/" VERSION,
+                                               NULL);
+
+  g_object_set (the_session, "ssl-strict", FALSE, NULL);
+
+  /* Cookie handling - stored temporarlly in memory, mostly useful for
+   * authentication in WebDAV. */
+  cookie_jar = g_object_new (SOUP_TYPE_COOKIE_JAR, NULL);
+  soup_session_add_feature (the_session, cookie_jar);
+  g_object_unref (cookie_jar);
+
+  /* Send Accept-Language header (see bug 166795) */
+  g_object_set (the_session, "accept-language-auto", TRUE, NULL);
+
+  /* Logging */
+  debug = g_getenv ("GVFS_HTTP_DEBUG");
+  if (debug)
+    {
+      SoupLogger         *logger;
+      SoupLoggerLogLevel  level;
+
+      if (g_ascii_strcasecmp (debug, "all") ||
+          g_ascii_strcasecmp (debug, "body"))
+        level = SOUP_LOGGER_LOG_BODY;
+      else if (g_ascii_strcasecmp (debug, "header"))
+        level = SOUP_LOGGER_LOG_HEADERS;
+      else
+        level = SOUP_LOGGER_LOG_MINIMAL;
+
+      logger = soup_logger_new (level, DEBUG_MAX_BODY_SIZE);
+      soup_session_add_feature (the_session, SOUP_SESSION_FEATURE (logger));
+      g_object_unref (logger);
+    }
 }
